---
title: <span class="badge object-type-scalar"></span> MicrogramPerCubicMeter
---
# <span class="badge object-type-scalar"></span> MicrogramPerCubicMeter

Concentration: microgram per cubic meter (μg/m³)

## Definition

```python
# Concentration: microgram per cubic meter (μg/m³)
MicrogramPerCubicMeter: typing.Literal["conμgm3"] = "conμgm3"
```
